@@ -1,4 +1,5 @@
 """Censys ASM CLI."""
+
 import argparse
 import concurrent.futures
 import csv
@@ -546,6 +547,13 @@ def cli_execute_saved_query_by_name(args: argparse.Namespace):
     Args:
         args (Namespace): Argparse Namespace.
     """
+    # do some sanity checking on page size before anything else
+    if args.page_size > 1000:
+        console.print(
+            "page size must be within [0,1000]. To fetch all pages, specify --pages -1 with any legal page size"
+        )
+
+        sys.exit(1)
     s = InventorySearch(args.api_key)
     q = SavedQueries(args.api_key)
     # get query from name
@@ -572,6 +580,13 @@ def cli_execute_saved_query_by_id(args: argparse.Namespace):
     Args:
         args (Namespace): Argparse Namespace.
     """
+    # do some sanity checking on page size before anything else
+    if args.page_size > 1000:
+        console.print(
+            "page size must be within [0,1000]. To fetch all pages, specify --pages -1 with any legal page size"
+        )
+
+        sys.exit(1)
     s = InventorySearch(args.api_key)
     q = SavedQueries(args.api_key)
     try:
